@@ -11,12 +11,15 @@ import typing_extensions
 import aws_cdk.aws_autoscaling._jsii
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_lambda._jsii
+import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.core._jsii
+import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-k3s-cluster", "0.0.9", __name__[0:-6], "cdk-k3s-cluster@0.0.9.jsii.tgz"
+    "cdk-k3s-cluster", "0.0.10", __name__[0:-6], "cdk-k3s-cluster@0.0.10.jsii.tgz"
 )
 
 __all__ = [
